import { select, csv, 
        scaleLinear, max, 
        scaleBand, axisLeft, 
        axisBottom, format } from 'd3';


const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

const render = data => {
  	const xValue = d => d.population;
  	const yValue = d => d.country;
  	const margin = { left:180, top:50, right:40, bottom:70 };
  	const innerWidth = width - margin.left - margin.right;
  	const innerHeight = height - margin.top - margin.bottom;
  
  	const xScale = scaleLinear()
    	.domain([0, max(data, xValue)])
    	.range([0, innerWidth])
  	;
  
  	const yScale = scaleBand()
    	.domain(data.map(d => d.country))
    	.range([0, innerHeight])
    	.padding(0.1)
    ;
    
		//const yAxis = axisLeft(yScale);
  	
  
  	const g = svg.append('g')
    	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  	const xAxisTickFormat = number => 
    	format('.3s')(number).replace('G', 'B');
  
  	const xAxis = axisBottom(xScale)
    	.tickFormat(xAxisTickFormat)
    	.tickSize(-innerHeight)
    	;
  
  	//yAxis(g.append('g'));
  	g.append('g')
      	.call(axisLeft(yScale))
  			.selectAll('.domain, .tick line')
  				.remove()
  		;
  
  
  	const xAixsGrp = g.append('g').call(xAxis)
  		.attr('transform', `translate(0, ${innerHeight})`);
  
  	xAixsGrp.select('.domain').remove();
  
  	xAixsGrp.append('text')
  		.attr('class', 'axis-label')
  		.attr('y', 60)
  		.attr('x', innerWidth/2)
  		.text("Population")
  		//.style('fill', 'red')
  	;
  
		g.selectAll('rect')
  		.data(data)
  		.enter()
  		.append('rect')
  			.attr('y', d => yScale(yValue(d)))
        .attr('width', d => xScale(xValue(d)))
        .attr('height', yScale.bandwidth())
  			//how do I set x, y according to data?
  			
  	g.append('text')
  		.attr('class', 'chart-title')
  		.attr('y', -10)
      .text("Top 10 Most Populous Countries");
	};

csv('data.csv').then(data => {
  data.forEach(d => {
    d.population = +d.population * 1000;
  });
  render(data);
});